@@ -1,9 +1,9 @@
 from pathlib import Path
 
 from archinstall.lib.disk.device_handler import device_handler
-from archinstall.lib.models.device_model import DiskLayoutConfiguration, DiskLayoutType
+from archinstall.lib.models.device import DiskLayoutConfiguration, DiskLayoutType
 
-root_mount_dir = Path("/mnt/archinstall")
+root_mount_dir = Path('/mnt/archinstall')
 
 mods = device_handler.detect_pre_mounted_mods(root_mount_dir)
 
